odin_uri

package module
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2023 License: MIT Imports: 5 Imported by: 0

README

Odin URI


This library is a component of the greater Odin project. Go to the official Vexxil site for more information on the project.

This project is not quite ready for open contributions, but is close. Check back if you are interested in contributing.

URI library based on RFC-3986 Uniform Resource Identifier (URI): Generic Syntax.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type URI

type URI interface {
	Schema() string
	Authority() string
}

func ParseUri

func ParseUri(value string) (URI, error)

Jump to